@@ -2067,7 +2067,7 @@ def override(context, team_name, engineer, hours, start_date, end_date):  # pyli
     Examples:
     $ opsgeniecli.py override --team_name <TEAMSCHEDULE> --engineer <ENGINEER> --hours <INTEGER>
     $ opsgeniecli.py override --team_name <TEAMSCHEDULE> --engineer <ENGINEER>
-    --start_date 2019-03-15T14:34:09 --end_date 2019-03-15T15:34:09
+    --start-date 2019-03-15T14:34:09 --end-date 2019-03-15T15:34:09
 
     """
     if team_name:
@@ -2077,16 +2077,18 @@ def override(context, team_name, engineer, hours, start_date, end_date):  # pyli
         start_dt = pendulum.now(tz='Europe/Amsterdam')
         end_dt = start_dt.add(hours=hours)
     elif start_date and end_date:
-        start_dt = pendulum.parse(start_date, tz='Europe/Amsterdam')
-        end_dt = pendulum.parse(end_date, tz='Europe/Amsterdam')
-        result = context.obj['opsgenie'].set_override_scheduled(team_name, start_dt.isoformat(), end_dt.isoformat(), engineer)
+        start_dt = pendulum.parse(start_date, tz='Europe/Amsterdam').in_tz('UTC').format('YYYY-MM-DDTHH:mm:ss\Z')
+        end_dt = pendulum.parse(end_date, tz='Europe/Amsterdam').in_tz('UTC').format('YYYY-MM-DDTHH:mm:ss\Z')
+        result = context.obj['opsgenie'].set_override_scheduled(team_name, start_dt, end_dt, engineer)
     else:
         raise click.UsageError(
             "Specify the amount of hours you want to override the schedule (using --hours), \
             or specify a schedule (using --start_date and --end_date)."
         )
     if result.status_code == 201:
-        print(f"✓ - override set to {engineer} between {start_dt.to_datetime_string()} and {end_dt.to_datetime_string()}")
+        start = pendulum.parse(start_date, tz='Europe/Amsterdam').to_datetime_string()
+        end = pendulum.parse(end_date, tz='Europe/Amsterdam').to_datetime_string()
+        print(f"✓ - override set to {engineer} between {start} and {end}")
     else:
         print(result.text)
 
